@@ -1,20 +1,20 @@
-
-# Copyright (C) 2012  LIGO Scientific Collaboration
+# -*- coding: utf-8 -*-
+# Copyright (C) Brian Moe, Branson Stephens (2015)
 #
-# This program is free software; you can redistribute it and/or modify it
-# under the terms of the GNU General Public License as published by the
-# Free Software Foundation; either version 3 of the License, or (at your
-# option) any later version.
+# This file is part of gracedb
 #
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
-# Public License for more details.
+# gracedb is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 #
-# You should have received a copy of the GNU General Public License along
-# with this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
+# It is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with gracedb.  If not, see <http://www.gnu.org/licenses/>.
 
 import httplib, socket, ssl
 import mimetypes
@@ -26,6 +26,7 @@ from base64 import b64encode
 import netrc
 
 DEFAULT_SERVICE_URL = "https://gracedb.ligo.org/api/"
+DEFAULT_BASIC_SERVICE_URL = "https://gracedb.ligo.org/apibasic/"
 KNOWN_TEST_HOSTS = ['moe.phys.uwm.edu', 'embb-dev.ligo.caltech.ed', 'simdb.phys.uwm.edu',]
 
 #-----------------------------------------------------------------
@@ -36,6 +37,7 @@ KNOWN_TEST_HOSTS = ['moe.phys.uwm.edu', 'embb-dev.ligo.caltech.ed', 'simdb.phys.
 # That would make putting our lists into comma-separated strings 
 # unnecessary.
 def cleanListInput(list_arg):
+    stringified_list = list_arg
     if isinstance(list_arg, float) or isinstance(list_arg, int):
         stringified_value = str(list_arg)
         return stringified_value
@@ -339,7 +341,7 @@ class GraceDb(GsiRest):
                 if name == input_value][0]
 
     # Search and filecontents are optional when creating an event.
-    def createEvent(self, group, pipeline, filename, search=None, filecontents=None):
+    def createEvent(self, group, pipeline, filename, search=None, filecontents=None, **kwargs):
         """Create a new GraceDB event
 
         Required args: group, pipeline, filename
@@ -380,6 +382,11 @@ class GraceDb(GsiRest):
                  ]
         if search:
             fields.append(('search', search))
+
+        # Update fields with additional keyword arguments
+        for key, value in kwargs.iteritems():
+            fields.append((key, value))
+
         files = [('eventFile', filename, filecontents)]
         # Python httplib bug?  unicode link
         uri = str(self.links['events'])
@@ -926,7 +933,7 @@ class GraceDbBasic(GraceDb):
     GraceDB behind a proxy. For other kwargs accepted by the constructor,
     consult the source code.
     """
-    def __init__(self, service_url=DEFAULT_SERVICE_URL,
+    def __init__(self, service_url=DEFAULT_BASIC_SERVICE_URL,
             proxy_host=None, proxy_port=3128, username=None, password=None, 
             *args, **kwargs):
 
