@@ -1,3 +1,20 @@
+# -*- coding: utf-8 -*-
+# Copyright (C) Brian Moe, Branson Stephens (2015)
+#
+# This file is part of gracedb
+#
+# gracedb is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# It is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with gracedb.  If not, see <http://www.gnu.org/licenses/>.
 
 import unittest
 import random
@@ -210,6 +227,18 @@ class TestGracedb(unittest.TestCase):
         self.assertEqual(float(mbta_event['gpstime']), 1078903329.421037)
         self.assertEqual(mbta_event['far'], 4.006953918826065e-7)
 
+    def test_create_hardwareinjection(self):
+        """Create a HardwareInjection event"""
+        """sim-inj.xml"""
+        eventFile = os.path.join(testdatadir, "sim-inj.xml")
+        hardwareinjection_event = gracedb.createEvent(
+                "Test", "HardwareInjection", eventFile,
+                instrument="H1", source_channel="H1:LDAS-STRAIN",
+                destination_channel="H1:LDAS-STRAIN_CBC_INJ").json()
+        self.assertEqual(hardwareinjection_event['group'], "Test")
+        self.assertEqual(hardwareinjection_event['pipeline'], "HardwareInjection")
+        self.assertEqual(hardwareinjection_event['instruments'], "H1")
+
     def test_replace_event(self):
         graceid = eventId
 
@@ -280,7 +309,7 @@ class TestGracedb(unittest.TestCase):
     def test_gittag(self):
         # try to make sure GIT_TAG is set properly.
         import errno
-        version = "1.18"
+        version = "1.19"
         try:
             # If we are in the source dir (setup.py is available)
             # make sure the version above agrees.
